diff decoders/mp3.c @ 221:c9772a9f5271

Initial implementation or stubs for rewind method. Other cleanups.
author Ryan C. Gordon <icculus@icculus.org>
date Thu, 17 Jan 2002 20:53:53 +0000
parents 5b311ffabe45
children d3dc34315ac7
line wrap: on
line diff
--- a/decoders/mp3.c	Thu Jan 17 20:53:03 2002 +0000
+++ b/decoders/mp3.c	Thu Jan 17 20:53:53 2002 +0000
@@ -56,6 +56,7 @@
 static int MP3_open(Sound_Sample *sample, const char *ext);
 static void MP3_close(Sound_Sample *sample);
 static Uint32 MP3_read(Sound_Sample *sample);
+static int MP3_rewind(Sound_Sample *sample);
 
 static const char *extensions_smpeg[] = { "MP3", "MPEG", "MPG", NULL };
 const Sound_DecoderFunctions __Sound_DecoderFunctions_MP3 =
@@ -67,11 +68,12 @@
         "http://www.lokigames.com/development/smpeg.php3"
     },
 
-    MP3_init,       /*  init() method */
-    MP3_quit,       /*  quit() method */
-    MP3_open,       /*  open() method */
-    MP3_close,      /* close() method */
-    MP3_read        /*  read() method */
+    MP3_init,       /*   init() method */
+    MP3_quit,       /*   quit() method */
+    MP3_open,       /*   open() method */
+    MP3_close,      /*  close() method */
+    MP3_read,       /*   read() method */
+    MP3_rewind      /* rewind() method */
 };
 
 
@@ -254,6 +256,15 @@
     return(retval);
 } /* MP3_read */
 
+
+static int MP3_rewind(Sound_Sample *sample)
+{
+    /* !!! FIXME. */
+    SNDDBG(("MP3_rewind(): Write me!\n"));
+    assert(0);
+    return(0);
+} /* MP3_rewind */
+
 #endif /* SOUND_SUPPORTS_MP3 */
 
 /* end of mp3.c ... */